@@ -4,7 +4,7 @@
  * 
  * hoel-sqlite.c: Sqlite3 specific functions
  * 
- * Copyright 2015-2016 Nicolas Mora <mail@babelouest.org>
+ * Copyright 2015-2020 Nicolas Mora <mail@babelouest.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -42,27 +42,34 @@ struct _h_sqlite {
  */
 struct _h_connection * h_connect_sqlite(const char * db_path) {
   struct _h_connection * conn = NULL;
+  o_malloc_t malloc_fn;
+  o_free_t free_fn;
+  
+  o_get_alloc_funcs(&malloc_fn, NULL, &free_fn);
+  json_set_alloc_funcs((json_malloc_t)malloc_fn, (json_free_t)free_fn);
+
   if (db_path != NULL) {
-    conn = malloc(sizeof(struct _h_connection));
+    conn = o_malloc(sizeof(struct _h_connection));
     if (conn == NULL) {
       y_log_message(Y_LOG_LEVEL_ERROR, "h_connect_sqlite - Error allocating resources");
       return NULL;
     }
     
     conn->type = HOEL_DB_TYPE_SQLITE;
-    conn->connection = malloc(sizeof(struct _h_sqlite));
+    conn->connection = o_malloc(sizeof(struct _h_sqlite));
     if (conn->connection == NULL) {
       y_log_message(Y_LOG_LEVEL_ERROR, "h_connect_sqlite - Error allocating resources");
-      free(conn);
+      o_free(conn);
       return NULL;
     }
-    if (sqlite3_open_v2(db_path, &((struct _h_sqlite *)conn->connection)->db_handle, SQLITE_OPEN_READWRITE, NULL) != SQLITE_OK) {
+    if (sqlite3_open_v2(db_path, &((struct _h_sqlite *)conn->connection)->db_handle, SQLITE_OPEN_READWRITE|SQLITE_OPEN_FULLMUTEX, NULL) != SQLITE_OK) {
       y_log_message(Y_LOG_LEVEL_ERROR, "Error connecting to sqlite3 database, path: %s", db_path);
       y_log_message(Y_LOG_LEVEL_DEBUG, "Error code: %d, message: \"%s\"", 
                              sqlite3_errcode(((struct _h_sqlite *)conn->connection)->db_handle), 
                              sqlite3_errmsg(((struct _h_sqlite *)conn->connection)->db_handle));
       sqlite3_close(((struct _h_sqlite *)conn->connection)->db_handle);
-      free(conn);
+      o_free(conn->connection);
+      o_free(conn);
       return NULL;
     } else {
       return conn;
@@ -99,10 +106,27 @@ char * h_escape_string_sqlite(const struct _h_connection * conn, const char * un
   return ret;
 }
 
+/**
+ * Escapes a string and returns it ready to be inserted in the query
+ * returned value must be free'd after use
+ */
+char * h_escape_string_with_quotes_sqlite(const struct _h_connection * conn, const char * unsafe) {
+  char * tmp = h_escape_string_sqlite(conn, unsafe), * ret;
+  if (tmp == NULL) {
+    return NULL;
+  }
+  ret = msprintf("'%s'", tmp);
+  o_free(tmp);
+  if (ret == NULL) {
+    y_log_message(Y_LOG_LEVEL_ERROR, "Error escaping with quotes (o_strdup)");
+  }
+  return ret;
+}
+
 /**
  * Return the id of the last inserted value
  */
-int h_last_insert_id_sqlite(const struct _h_connection * conn) {
+long long int h_last_insert_id_sqlite(const struct _h_connection * conn) {
   return sqlite3_last_insert_rowid(((struct _h_sqlite *)conn->connection)->db_handle);
 }
 
@@ -136,7 +160,7 @@ int h_select_query_sqlite(const struct _h_connection * conn, const char * query,
           data = NULL;
           switch (sqlite3_column_type(stmt, col)) {
             case SQLITE_INTEGER:
-              data = h_new_data_int(sqlite3_column_int(stmt, col));
+              data = h_new_data_int(sqlite3_column_int64(stmt, col));
               break;
             case SQLITE_FLOAT:
               data = h_new_data_double(sqlite3_column_double(stmt, col));
@@ -245,7 +269,7 @@ int h_execute_query_json_sqlite(const struct _h_connection * conn, const char *
       for (col = 0; col < nb_columns; col++) {
         switch (sqlite3_column_type(stmt, col)) {
           case SQLITE_INTEGER:
-            json_object_set_new(j_data, sqlite3_column_name(stmt, col), json_integer(sqlite3_column_int(stmt, col)));
+            json_object_set_new(j_data, sqlite3_column_name(stmt, col), json_integer(sqlite3_column_int64(stmt, col)));
             break;
           case SQLITE_FLOAT:
             json_object_set_new(j_data, sqlite3_column_name(stmt, col), json_real(sqlite3_column_double(stmt, col)));
