@@ -4,7 +4,7 @@
  * 
  * hoel.c: main functions
  * 
- * Copyright 2015-2016 Nicolas Mora <mail@babelouest.org>
+ * Copyright 2015-2020 Nicolas Mora <mail@babelouest.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -93,6 +93,35 @@ char * h_escape_string(const struct _h_connection * conn, const char * unsafe) {
   }
 }
 
+/**
+ * h_escape_string_with_quotes
+ * Escapes a string and returns it ready to be inserted in the query
+ * returned value must be h_h_free'd after use
+ */
+char * h_escape_string_with_quotes(const struct _h_connection * conn, const char * unsafe) {
+  if (conn != NULL && conn->connection != NULL && unsafe != NULL) {
+    if (0) {
+      /* Not happening */
+#ifdef _HOEL_SQLITE
+    } else if (conn->type == HOEL_DB_TYPE_SQLITE) {
+      return h_escape_string_with_quotes_sqlite(conn, unsafe);
+#endif
+#ifdef _HOEL_MARIADB
+    } else if (conn->type == HOEL_DB_TYPE_MARIADB) {
+      return h_escape_string_with_quotes_mariadb(conn, unsafe);
+#endif
+#ifdef _HOEL_PGSQL
+    } else if (conn->type == HOEL_DB_TYPE_PGSQL) {
+      return h_escape_string_with_quotes_pgsql(conn, unsafe);
+#endif
+    } else {
+      return NULL;
+    }
+  } else {
+    return NULL;
+  }
+}
+
 /**
  * h_execute_query
  * Execute a query, set the result structure with the returned values if available
@@ -443,7 +472,7 @@ int h_clean_data_full(struct _h_data * data) {
  * return pointer to the new structure
  * return NULL on error
  */
-struct _h_data * h_new_data_int(const int value) {
+struct _h_data * h_new_data_int(const long long int value) {
   struct _h_data * data = o_malloc(sizeof(struct _h_data));
   if (data != NULL) {
     data->t_data = o_malloc(sizeof(struct _h_type_int));
