@@ -19,32 +19,32 @@
 
 #define UNSAFE_STRING "un'safe' (\"string\")#!/$%*];"
 
-#define SELECT_DATA_1 "SELECT `integer_col`, `string_col`, `date_col` FROM `test_table` WHERE `integer_col` = 1"
-#define SELECT_DATA_2 "SELECT `integer_col`, `string_col`, `date_col` FROM `test_table` WHERE `integer_col` = 2"
-#define SELECT_DATA_ERROR "SELECT `integer_col`, `string_col`, `date_col` FROM `test_table` WHERE `integer_col` = 'error'"
-#define SELECT_DATA_ALL "SELECT * FROM `test_table`"
+#define SELECT_DATA_1 "SELECT integer_col, string_col, date_col FROM test_table WHERE integer_col = 1"
+#define SELECT_DATA_2 "SELECT integer_col, string_col, date_col FROM test_table WHERE integer_col = 2"
+#define SELECT_DATA_ERROR "SELECT integer_col, string_col, date_col FROM test_table WHERE integer_col = 'error'"
+#define SELECT_DATA_ALL "SELECT * FROM test_table"
 
-#define INSERT_DATA_1 "INSERT INTO `test_table` (`integer_col`, `string_col`, `date_col`) VALUES (1, 'value1', date('now'))"
-#define INSERT_DATA_2 "INSERT INTO `test_table` (`integer_col`, `string_col`, `date_col`) VALUES (2, 'value2', strftime('%s','2016-06-22 00:52:56'))"
-#define INSERT_DATA_ERROR "INSERT INTO `test_table` (`integer_col`, `string_col`, `date_col`) VALUES ('error', 'value error', date('now'))"
+#define INSERT_DATA_1 "INSERT INTO test_table (integer_col, string_col, date_col) VALUES (1, 'value1', date('now'))"
+#define INSERT_DATA_2 "INSERT INTO test_table (integer_col, string_col, date_col) VALUES (2, 'value2', strftime('%s','2016-06-22 00:52:56'))"
+#define INSERT_DATA_ERROR "INSERT INTO test_table (integer_col, string_col, date_col) VALUES ('error', 'value error', date('now'))"
 
-#define DELETE_DATA_1 "DELETE FROM `test_table` WHERE `integer_col` = 1"
-#define DELETE_DATA_2 "DELETE FROM `test_table` WHERE `integer_col` = 2"
-#define DELETE_DATA_ERROR "DELETE FROM `test_table` WHERE `wrong_table` = 1"
-#define DELETE_DATA_ALL "DELETE FROM `test_table`"
+#define DELETE_DATA_1 "DELETE FROM test_table WHERE integer_col = 1"
+#define DELETE_DATA_2 "DELETE FROM test_table WHERE integer_col = 2"
+#define DELETE_DATA_ERROR "DELETE FROM test_table WHERE wrong_table = 1"
+#define DELETE_DATA_ALL "DELETE FROM test_table"
 
-#define UPDATE_DATA_1 "UPDATE `test_table` SET `string_col`='new value1' WHERE `integer_col` = 1"
+#define UPDATE_DATA_1 "UPDATE test_table SET string_col='new value1' WHERE integer_col = 1"
 
 const char * db_path;
 
 void print_result(struct _h_result result) {
-  int col, row, i;
+  size_t col, row, i;
   printf("rows: %u, col: %u\n", result.nb_rows, result.nb_columns);
   for (row = 0; row<result.nb_rows; row++) {
     for (col=0; col<result.nb_columns; col++) {
       switch(result.data[row][col].type) {
         case HOEL_COL_TYPE_INT:
-          printf("| %d ", ((struct _h_type_int *)result.data[row][col].t_data)->value);
+          printf("| %lld ", ((struct _h_type_int *)result.data[row][col].t_data)->value);
           break;
         case HOEL_COL_TYPE_DOUBLE:
           printf("| %f ", ((struct _h_type_double *)result.data[row][col].t_data)->value);
@@ -94,8 +94,40 @@ START_TEST(test_hoel_escape_string)
   escaped = h_escape_string(conn, "value");
   ck_assert_str_eq(escaped, "value");
   h_free(escaped);
-  escaped = h_escape_string(conn, "`unsafe ' value\"!");
-  ck_assert_str_eq(escaped, "`unsafe '' value\"!");
+  escaped = h_escape_string(conn, "unsafe ' value\"!");
+  ck_assert_str_eq(escaped, "unsafe '' value\"!");
+  h_free(escaped);
+  
+  j_query = json_pack("{sss{siss}}", "table", "test_table", "values", "integer_col", 666, "string_col", UNSAFE_STRING);
+  res = h_insert(conn, j_query, NULL);
+  json_decref(j_query);
+  ck_assert_int_eq(res, H_OK);
+  j_query = json_pack("{sss[s]s{si}}", "table", "test_table", "columns", "string_col", "where", "integer_col", 666);
+  res = h_select(conn, j_query, &j_result, NULL);
+  json_decref(j_query);
+  ck_assert_int_eq(res, H_OK);
+  ck_assert_str_eq(UNSAFE_STRING, json_string_value(json_object_get(json_array_get(j_result, 0), "string_col")));
+  json_decref(j_result);
+  
+  ck_assert_int_eq(h_close_db(conn), H_OK);
+  ck_assert_int_eq(h_clean_connection(conn), H_OK);
+}
+END_TEST
+
+START_TEST(test_hoel_escape_string_with_quotes)
+{
+  struct _h_connection * conn;
+  char * escaped;
+  json_t * j_query, * j_result;
+  int res;
+  
+  conn = h_connect_sqlite(db_path);
+  ck_assert_ptr_ne(conn, NULL);
+  escaped = h_escape_string_with_quotes(conn, "value");
+  ck_assert_str_eq(escaped, "'value'");
+  h_free(escaped);
+  escaped = h_escape_string_with_quotes(conn, "unsafe ' value\"!");
+  ck_assert_str_eq(escaped, "'unsafe '' value\"!'");
   h_free(escaped);
   
   j_query = json_pack("{sss{siss}}", "table", "test_table", "values", "integer_col", 666, "string_col", UNSAFE_STRING);
@@ -244,7 +276,7 @@ START_TEST(test_hoel_json_insert)
   ck_assert_str_eq(json_string_value(json_object_get(json_array_get(j_result, 0), "string_col")), "value1");
   ck_assert_int_eq(json_integer_value(json_object_get(json_array_get(j_result, 0), "integer_col")), 1);
   json_decref(j_result);
-  ck_assert_int_eq(strlen(str_query), strlen("INSERT INTO `test_table` (`integer_col`,`string_col`,`date_col`) VALUES (1,'value1',date('now'))"));
+  ck_assert_int_eq(strlen(str_query), strlen("INSERT INTO test_table (integer_col,string_col,date_col) VALUES (1,'value1',date('now'))"));
   h_free(str_query);
   ck_assert_int_eq(h_delete(conn, j_query, NULL), H_OK);
   json_decref(j_query);
@@ -298,7 +330,7 @@ START_TEST(test_hoel_json_update)
                         1);
   ck_assert_int_eq(h_update(conn, j_query, &str_query), H_OK);
   json_decref(j_query);
-  ck_assert_int_eq(strlen(str_query), strlen("UPDATE `test_table` SET `string_col`='new value1' WHERE integer_col='1'"));
+  ck_assert_int_eq(strlen(str_query), strlen("UPDATE test_table SET string_col='new value1' WHERE integer_col='1'"));
   h_free(str_query);
   j_query = json_pack("{sss{si}}",
                       "table",
@@ -368,7 +400,7 @@ START_TEST(test_hoel_json_delete)
                         "integer_col",
                         1);
   ck_assert_int_eq(h_delete(conn, j_query, &str_query), H_OK);
-  ck_assert_int_eq(strlen(str_query), strlen("DELETE FROM `test_table` WHERE integer_col='1'"));
+  ck_assert_int_eq(strlen(str_query), strlen("DELETE FROM test_table WHERE integer_col='1'"));
   h_free(str_query);
   json_decref(j_query);
   j_query = json_pack("{ss}",
@@ -432,7 +464,7 @@ START_TEST(test_hoel_json_select)
                       "table",
                       "test_table");
   ck_assert_int_eq(h_select(conn, j_query, &j_result, &str_query), H_OK);
-  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM `test_table` WHERE 1=1  "));
+  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM test_table WHERE 1=1  "));
   ck_assert_int_eq(json_array_size(j_result), 2);
   ck_assert_str_eq(json_string_value(json_object_get(json_array_get(j_result, 0), "string_col")), "value1");
   ck_assert_int_eq(json_integer_value(json_object_get(json_array_get(j_result, 0), "integer_col")), 1);
@@ -447,7 +479,7 @@ START_TEST(test_hoel_json_select)
                         "integer_col",
                         1);
   ck_assert_int_eq(h_select(conn, j_query, &j_result, &str_query), H_OK);
-  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM `test_table` WHERE integer_col='1'  "));
+  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM test_table WHERE integer_col='1'  "));
   ck_assert_int_eq(json_array_size(j_result), 1);
   ck_assert_str_eq(json_string_value(json_object_get(json_array_get(j_result, 0), "string_col")), "value1");
   ck_assert_int_eq(json_integer_value(json_object_get(json_array_get(j_result, 0), "integer_col")), 1);
@@ -462,7 +494,7 @@ START_TEST(test_hoel_json_select)
                         "string_col",
                         "value1");
   ck_assert_int_eq(h_select(conn, j_query, &j_result, &str_query), H_OK);
-  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM `test_table` WHERE string_col='value1'  "));
+  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM test_table WHERE string_col='value1'  "));
   ck_assert_int_eq(json_array_size(j_result), 1);
   ck_assert_str_eq(json_string_value(json_object_get(json_array_get(j_result, 0), "string_col")), "value1");
   ck_assert_int_eq(json_integer_value(json_object_get(json_array_get(j_result, 0), "integer_col")), 1);
@@ -477,7 +509,7 @@ START_TEST(test_hoel_json_select)
                         "string_col",
                         "value'to'escape");
   ck_assert_int_eq(h_select(conn, j_query, &j_result, &str_query), H_OK);
-  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM `test_table` WHERE string_col='value''to''escape'  "));
+  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM test_table WHERE string_col='value''to''escape'  "));
   ck_assert_int_eq(json_array_size(j_result), 0);
   json_decref(j_query);
   json_decref(j_result);
@@ -491,7 +523,7 @@ START_TEST(test_hoel_json_select)
                           "operator",
                           "NOT NULL");
   ck_assert_int_eq(h_select(conn, j_query, &j_result, &str_query), H_OK);
-  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM `test_table` WHERE integer_col IS NOT NULL  "));
+  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM test_table WHERE integer_col IS NOT NULL  "));
   ck_assert_int_eq(json_array_size(j_result), 2);
   ck_assert_str_eq(json_string_value(json_object_get(json_array_get(j_result, 0), "string_col")), "value1");
   ck_assert_int_eq(json_integer_value(json_object_get(json_array_get(j_result, 0), "integer_col")), 1);
@@ -509,7 +541,7 @@ START_TEST(test_hoel_json_select)
                           "value",
                           ">6");
   ck_assert_int_eq(h_select(conn, j_query, &j_result, &str_query), H_OK);
-  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM `test_table` WHERE integer_col >6  "));
+  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM test_table WHERE integer_col >6  "));
   ck_assert_int_eq(json_array_size(j_result), 0);
   json_decref(j_query);
   json_decref(j_result);
@@ -528,7 +560,7 @@ START_TEST(test_hoel_json_select)
                           "value",
                           ">=1");
   ck_assert_int_eq(h_select(conn, j_query, &j_result, &str_query), H_OK);
-  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM `test_table` WHERE string_col IS NOT NULL AND integer_col >=1  "));
+  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM test_table WHERE string_col IS NOT NULL AND integer_col >=1  "));
   ck_assert_int_eq(json_array_size(j_result), 2);
   ck_assert_str_eq(json_string_value(json_object_get(json_array_get(j_result, 0), "string_col")), "value1");
   ck_assert_int_eq(json_integer_value(json_object_get(json_array_get(j_result, 0), "integer_col")), 1);
@@ -543,7 +575,7 @@ START_TEST(test_hoel_json_select)
                         "integer_col",
                         json_null());
   ck_assert_int_eq(h_select(conn, j_query, &j_result, &str_query), H_OK);
-  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM `test_table` WHERE integer_col IS NULL  "));
+  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM test_table WHERE integer_col IS NULL  "));
   ck_assert_int_eq(json_array_size(j_result), 0);
   json_decref(j_query);
   json_decref(j_result);
@@ -562,7 +594,7 @@ START_TEST(test_hoel_json_select)
                             42,
                             66);
   ck_assert_int_eq(h_select(conn, j_query, &j_result, &str_query), H_OK);
-  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM `test_table` WHERE integer_col IN (42,66)  "));
+  ck_assert_int_eq(strlen(str_query), strlen("SELECT * FROM test_table WHERE integer_col IN (42,66)  "));
   ck_assert_int_eq(json_array_size(j_result), 0);
   json_decref(j_query);
   json_decref(j_result);
@@ -590,6 +622,7 @@ static Suite *hoel_suite(void)
 	tc_core = tcase_create("test_hoel_core");
 	tcase_add_test(tc_core, test_hoel_init);
 	tcase_add_test(tc_core, test_hoel_escape_string);
+	tcase_add_test(tc_core, test_hoel_escape_string_with_quotes);
 	tcase_add_test(tc_core, test_hoel_insert);
 	tcase_add_test(tc_core, test_hoel_update);
 	tcase_add_test(tc_core, test_hoel_delete);
